==> haskell-unliftio-core-0.2.1.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio-core
version:              0.2.1.0
visibility:           public
id:                   unliftio-core-0.2.1.0-AJ3ipHGgln87h2Y2hfrpJj
key:                  unliftio-core-0.2.1.0-AJ3ipHGgln87h2Y2hfrpJj
license:              MIT
copyright:            2017-2020 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio-core#readme

synopsis:             The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>

category:             Control
abi:                  a0b92b4a4658f14d0953dbd4b8b805ab
exposed:              True
exposed-modules:      Control.Monad.IO.Unlift
hidden-modules:       Paths_unliftio_core
import-dirs:          /usr/lib/ghc-9.0.2/site-local/unliftio-core-0.2.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unliftio-core-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unliftio-core
hs-libraries:         HSunliftio-core-0.2.1.0-AJ3ipHGgln87h2Y2hfrpJj
depends:              base-4.15.1.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock

haddock-html:         /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-core-0.2.1.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio-core
version:              0.2.1.0
visibility:           public
id:                   unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
key:                  unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
license:              MIT
copyright:            2017-2020 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio-core#readme

synopsis:             The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>

category:             Control
abi:                  47bd8f9b4f3135c4625c4d3607180ec4
exposed:              True
exposed-modules:      Control.Monad.IO.Unlift
hidden-modules:       Paths_unliftio_core
import-dirs:          /usr/lib/ghc-9.2.8/site-local/unliftio-core-0.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/unliftio-core-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unliftio-core
hs-libraries:         HSunliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
depends:              base-4.16.4.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock

haddock-html:         /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
